@@ -28,13 +28,11 @@ from social_auth.utils import setting, model_to_ctype, ctype_to_model, \
                               get_random_string, constant_time_compare, \
                               dsa_urlopen
 from social_auth.store import DjangoOpenIDStore
-from social_auth.backends.exceptions import StopPipeline, AuthException, \
-                                            AuthFailed, AuthCanceled, \
-                                            AuthUnknownError, AuthTokenError, \
-                                            AuthMissingParameter, \
-                                            AuthStateMissing, \
-                                            AuthStateForbidden, \
-                                            NotAllowedToDisconnect
+from social_auth.exceptions import StopPipeline, AuthException, AuthFailed, \
+                                   AuthCanceled, AuthUnknownError, \
+                                   AuthTokenError, AuthMissingParameter, \
+                                   AuthStateMissing, AuthStateForbidden, \
+                                   NotAllowedToDisconnect
 from social_auth.backends.utils import build_consumer_oauth_request
 
 
@@ -619,18 +617,29 @@ class ConsumerBasedOAuth(BaseOAuth):
         """Return redirect url"""
         token = self.unauthorized_token()
         name = self.AUTH_BACKEND.name + 'unauthorized_token_name'
-        self.request.session[name] = token.to_string()
+        if not isinstance(self.request.session.get(name), list):
+            self.request.session[name] = []
+        self.request.session[name].append(token.to_string())
+        self.request.session.modified = True
         return self.oauth_authorization_request(token).to_url()
 
     def auth_complete(self, *args, **kwargs):
         """Return user, might be logged in"""
+        # Multiple unauthorized tokens are supported (see #521)
         name = self.AUTH_BACKEND.name + 'unauthorized_token_name'
-        unauthed_token = self.request.session.get(name)
-        if not unauthed_token:
+        token = None
+        unauthed_tokens = self.request.session.get(name) or []
+        if not unauthed_tokens:
             raise AuthTokenError(self, 'Missing unauthorized token')
-
-        token = Token.from_string(unauthed_token)
-        if token.key != self.data.get('oauth_token', 'no-token'):
+        for unauthed_token in unauthed_tokens:
+            token = Token.from_string(unauthed_token)
+            if token.key == self.data.get('oauth_token', 'no-token'):
+                unauthed_tokens = list(set(unauthed_tokens) - \
+                                       set([unauthed_token]))
+                self.request.session[name] = unauthed_tokens
+                self.request.session.modified = True
+                break
+        else:
             raise AuthTokenError(self, 'Incorrect tokens')
 
         try:
@@ -657,10 +666,12 @@ class ConsumerBasedOAuth(BaseOAuth):
 
     def unauthorized_token(self):
         """Return request for unauthorized token (first stage)"""
-        request = self.oauth_request(token=None, url=self.REQUEST_TOKEN_URL,
-                             extra_params=self.request_token_extra_arguments())
-        response = self.fetch_response(request)
-        return Token.from_string(response)
+        request = self.oauth_request(
+            token=None,
+            url=self.REQUEST_TOKEN_URL,
+            extra_params=self.request_token_extra_arguments()
+        )
+        return Token.from_string(self.fetch_response(request))
 
     def oauth_authorization_request(self, token):
         """Generate OAuth request to authorize token."""
@@ -742,7 +753,9 @@ class BaseOAuth2(BaseOAuth):
             # value is passed as state parameter (as specified in OAuth2 spec),
             # but also added to redirect_uri, that way we can still verify the
             # request if the provider doesn't implement the state parameter.
-            state = self.state_token()
+            # Reuse token if any.
+            name = self.AUTH_BACKEND.name + '_state'
+            state = self.request.session.get(name) or self.state_token()
             self.request.session[self.AUTH_BACKEND.name + '_state'] = state
         else:
             state = None
@@ -763,14 +776,15 @@ class BaseOAuth2(BaseOAuth):
         if not self.STATE_PARAMETER and not self.REDIRECT_STATE:
             return None
         state = self.request.session.get(self.AUTH_BACKEND.name + '_state')
-        request_state = self.data.get('state') or \
-                        self.data.get('redirect_state')
-        if not request_state:
-            raise AuthMissingParameter(self, 'state')
-        elif not state:
-            raise AuthStateMissing(self, 'state')
-        elif not constant_time_compare(request_state, state):
-            raise AuthStateForbidden(self)
+        if state:
+            request_state = self.data.get('state') or \
+                            self.data.get('redirect_state')
+            if not request_state:
+                raise AuthMissingParameter(self, 'state')
+            elif not state:
+                raise AuthStateMissing(self, 'state')
+            elif not constant_time_compare(request_state, state):
+                raise AuthStateForbidden(self)
         return state
 
     def process_error(self, data):
@@ -810,7 +824,8 @@ class BaseOAuth2(BaseOAuth):
             raise AuthUnknownError(self)
 
         self.process_error(response)
-        return self.do_auth(response['access_token'], response=response)
+        return self.do_auth(response['access_token'], response=response,
+                            *args, **kwargs)
 
     def do_auth(self, access_token, *args, **kwargs):
         """Finish the auth process once the access_token was retrieved"""
