@@ -1,15 +1,19 @@
 """Models mixins for Social Auth"""
 import base64
 import time
+import re
 from datetime import datetime, timedelta
 
 from openid.association import Association as OIDAssociation
 
 from social_auth.utils import setting, utc
 
+# django.contrib.auth and mongoengine.django.auth regex to validate usernames
+# '^[\w@.+-_]+$', we use the opposite to clean invalid characters
+CLEAN_USERNAME_REGEX = re.compile(r'[^\w.@+-_]+')
+
 
 class UserSocialAuthMixin(object):
-    User = None
     user = ''
     provider = ''
 
@@ -54,38 +58,61 @@ class UserSocialAuthMixin(object):
             else:  # expires is a timedelta
                 return timedelta(seconds=expires)
 
+    @classmethod
+    def user_model(cls):
+        raise NotImplementedError('Implement in subclass')
+
     @classmethod
     def username_max_length(cls):
         raise NotImplementedError('Implement in subclass')
 
+    @classmethod
+    def clean_username(cls, value):
+        return CLEAN_USERNAME_REGEX.sub('', value)
+
+    @classmethod
+    def allowed_to_disconnect(cls, user, backend_name, association_id=None):
+        if association_id is not None:
+            qs = cls.objects.exclude(id=association_id)
+        else:
+            qs = cls.objects.exclude(provider=backend_name)
+
+        if hasattr(user, 'has_usable_password'):
+            valid_password = user.has_usable_password()
+        else:
+            valid_password = True
+
+        return valid_password or qs.count() > 0
+
     @classmethod
     def simple_user_exists(cls, *args, **kwargs):
         """
         Return True/False if a User instance exists with the given arguments.
         Arguments are directly passed to filter() manager method.
         """
-        return cls.User.objects.filter(*args, **kwargs).count() > 0
+        return cls.user_model().objects.filter(*args, **kwargs).count() > 0
 
     @classmethod
-    def create_user(cls, *args, **kwargs):
-        return cls.User.objects.create(*args, **kwargs)
+    def create_user(cls, username, email=None):
+        return cls.user_model().objects.create_user(username=username,
+                                                    email=email)
 
     @classmethod
     def get_user(cls, pk):
         try:
-            return cls.User.objects.get(pk=pk)
-        except cls.User.DoesNotExist:
+            return cls.user_model().objects.get(pk=pk)
+        except cls.user_model().DoesNotExist:
             return None
 
     @classmethod
     def get_user_by_email(cls, email):
-        return cls.User.objects.get(email=email)
+        return cls.user_model().objects.get(email=email)
 
     @classmethod
     def resolve_user_or_id(cls, user_or_id):
-        if isinstance(user_or_id, cls.User):
+        if isinstance(user_or_id, cls.user_model()):
             return user_or_id
-        return cls.User.objects.get(pk=user_or_id)
+        return cls.user_model().objects.get(pk=user_or_id)
 
     @classmethod
     def get_social_auth(cls, provider, uid):
