@@ -16,17 +16,14 @@ from social_auth.utils import setting
 #   is_active  = BooleanField()
 #   def is_authenticated():
 #       ...
-if setting('SOCIAL_AUTH_USER_MODEL'):
-    UserModel = models.get_model(*setting('SOCIAL_AUTH_USER_MODEL')
-                                    .rsplit('.', 1))
-else:
-    from django.contrib.auth.models import User as UserModel
+USER_MODEL = setting('SOCIAL_AUTH_USER_MODEL') or \
+             setting('AUTH_USER_MODEL') or \
+             'auth.User'
 
 
 class UserSocialAuth(models.Model, UserSocialAuthMixin):
     """Social Auth association model"""
-    User = UserModel
-    user = models.ForeignKey(UserModel, related_name='social_auth')
+    user = models.ForeignKey(USER_MODEL, related_name='social_auth')
     provider = models.CharField(max_length=32)
     uid = models.CharField(max_length=255)
     extra_data = JSONField(default='{}')
@@ -36,10 +33,6 @@ class UserSocialAuth(models.Model, UserSocialAuthMixin):
         unique_together = ('provider', 'uid')
         app_label = 'social_auth'
 
-    @classmethod
-    def create_user(cls, *args, **kwargs):
-        return cls.User.objects.create_user(*args, **kwargs)
-
     @classmethod
     def get_social_auth(cls, provider, uid):
         try:
@@ -50,7 +43,12 @@ class UserSocialAuth(models.Model, UserSocialAuthMixin):
 
     @classmethod
     def username_max_length(cls):
-        return cls.User._meta.get_field('username').max_length
+        field = UserSocialAuth.user_model()._meta.get_field('username')
+        return field.max_length
+
+    @classmethod
+    def user_model(cls):
+        return UserSocialAuth._meta.get_field('user').rel.to
 
 
 class Nonce(models.Model, NonceMixin):
