@@ -3,6 +3,11 @@ MongoEngine models for Social Auth
 
 Requires MongoEngine 0.6.10
 """
+try:
+    from django.contrib.auth.hashers import UNUSABLE_PASSWORD
+except (ImportError, AttributeError):
+    UNUSABLE_PASSWORD = '!'
+
 from mongoengine import DictField, Document, IntField, ReferenceField, \
                         StringField
 from mongoengine.django.auth import User
@@ -42,8 +47,23 @@ class UserSocialAuth(Document, UserSocialAuthMixin):
         # Empty string makes email regex validation fail
         if email == '':
             email = None
-        return cls.user_model().objects.create_user(username=username,
-                                                    email=email)
+        return cls.user_model().create_user(username=username,
+                                            password=UNUSABLE_PASSWORD,
+                                            email=email)
+
+    @classmethod
+    def allowed_to_disconnect(cls, user, backend_name, association_id=None):
+        if association_id is not None:
+            qs = cls.objects.filter(id__ne=association_id)
+        else:
+            qs = cls.objects.filter(provider__ne=backend_name)
+
+        if hasattr(user, 'has_usable_password'):
+            valid_password = user.has_usable_password()
+        else:
+            valid_password = True
+
+        return valid_password or qs.count() > 0
 
 
 class Nonce(Document, NonceMixin):
